import glob
import os
from setuptools import setup, find_packages

# Utility function to read the README file.
# Used for the long_description.  It's nice, because now 1) we have a top level
# README file and 2) it's easier to type in the README file than to put a raw
# string in below. Stolen from
# https://pythonhosted.org/an_example_pypi_project/setuptools.html
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

# Allow modification of systemd install location via env var.
SYSTEMDUNITPATH = os.getenv("SYSTEMDUNITPATH", '/usr/lib/systemd/system')

setup(
    name = "relval",
    version = "2.0.0",
    entry_points = {'console_scripts': ['relval = relval.cli:main',
                                        'relval-fedmsg = relval.consumer:main'],},
    author = "Adam Williamson",
    author_email = "awilliam@redhat.com",
    description = ("Fedora QA wiki test validation event management tool"),
    license = "GPLv3+",
    keywords = "fedora qa mediawiki validation",
    url = "https://www.happyassassin.net/wikitcms/",
    packages = ["relval"],
    include_package_data = True,
    install_requires = ['wikitcms>=2.0.0', 'setuptools', 'markupsafe', 'six',
                        'fedfind>=2.0.0', 'mwclient', 'fedmsg'],
    long_description=read('README.md'),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Topic :: Utilities",
        "License :: OSI Approved :: GNU General Public License v3 or later "
        "(GPLv3+)",
    ],
    data_files=[
        (SYSTEMDUNITPATH, glob.glob('systemd/*.service')),
    ],
)
